@@ -64,7 +64,7 @@ describe 'heat' do
     it_configures 'with SSL disabled'
     it_configures 'with SSL wrongly configured'
     it_configures 'with enable_stack_adopt and enable_stack_abandon set'
-    it_configures 'with overriden transport_url parameter'
+    it_configures 'with overridden transport_url parameter'
     it_configures 'with notification_driver set to a string'
 
     context 'with amqp messaging' do
@@ -138,7 +138,7 @@ describe 'heat' do
     end
 
     it 'configures auth_uri for clients_keystone' do
-      is_expected.to contain_heat_config('clients_keystone/auth_uri').with_value( 'http://127.0.0.1:35357/' )
+      is_expected.to contain_heat_config('clients_keystone/auth_uri').with_value( 'http://127.0.0.1:5000/' )
     end
 
     it 'configures endpoint_type for clients' do
@@ -160,13 +160,15 @@ describe 'heat' do
     it { is_expected.to contain_heat_config('paste_deploy/flavor').with_value('keystone') }
 
     it 'configures notification_driver' do
-        is_expected.to contain_heat_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_heat_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_heat_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
     end
 
     it 'sets default value for http_proxy_to_wsgi middleware' do
-      is_expected.to contain_heat_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('heat_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      )
     end
 
     it 'sets clients_heat url' do
@@ -424,7 +426,7 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for 'with overriden transport_url parameter' do
+  shared_examples_for 'with overridden transport_url parameter' do
     before do
       params.merge!(
         :default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
@@ -476,7 +478,7 @@ describe 'heat' do
       it { is_expected.to contain_heat_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>') }
     end
 
-    context 'with overriden amqp parameters' do
+    context 'with overridden amqp parameters' do
       before { params.merge!(
         :amqp_idle_timeout  => '60',
         :amqp_trace         => true,
